@@ -1,7 +1,6 @@
 
 import numpy as np
-import scipy
-from scipy.misc import imread
+from imageio import imread
 from matplotlib import pyplot as ppl
 
 import maxflow
@@ -17,8 +16,6 @@ g.add_grid_edges(nodeids, 50)
 # Add the terminal edges.
 g.add_grid_tedges(nodeids, img, 255-img)
 
-graph = g.get_nx_graph()
-
 # Find the maximum flow.
 g.maxflow()
 # Get the segments.
